#!/bin/bash


# Create a new deploy for the service, echoing its path
#
# $ deploy_new www.ubuntu-it.org
# /srv/www.ubuntu-it.org/builds/XXXXXX
deploy_new() {
    name="$1"

    now="$(date +"%Y-%m-%d--%H-%M-%S")"

    build_dir="${DIR_BASE}/${name}/builds/${now}"
    mkdir -p "${build_dir}"

    echo "${build_dir}"
}


# Switch to a different deploy, cleaning up old ones
#
# $ deploy_switch www.ubuntu-it.org /srv/www.ubuntu-it.org/builds/XXXXXX
deploy_switch() {
    name="$1"
    build="$2"

    base="${DIR_BASE}/${name}"
    current="${base}/htdocs"

    # Switch the current/ symlink to the new build
    ln -sfT "${build}" "${current}"

    # Remove the oldest builds
    # shellcheck disable=2012
    mapfile -t directories < <(ls -t -d -1 "${base}/builds"/????-??-??--??-??-?? | awk "NR>${KEEP_BUILDS}")
    for dir in "${directories[@]}"; do
        # Avoid deleting the current build
        if [[ "${dir}" != "${build}" ]]; then
            rm -rf "${dir}"
        fi
    done
}
